﻿local MAJOR_VERSION = "Threat-1.0"
local MINOR_VERSION = tonumber(("$Revision: 38530 $"):match("%d+"))

if MINOR_VERSION > _G.ThreatLib_MINOR_VERSION then
	_G.ThreatLib_MINOR_VERSION = MINOR_VERSION
end

ThreatLib_funcs[#ThreatLib_funcs+1] = function()

local ThreatLib = _G.ThreatLib

local BB = AceLibrary("Babble-Boss-2.2")

-- You need to register the module with the localized mob name, as this is used to 
local c = BB["Leotheras the Blind"]

local Leotheras = ThreatLib:GetModule("NPCCore"):NewModule(c)

local demonTriggerStrings = {
	["enUS"] = "I am in control now!$",
	["deDE"] = "Ich habe jetzt die Kontrolle!",
	["frFR"] = "Je prends le contrôle !$",
	["koKR"] = "꺼져라, 엘프 꼬맹이. 지금부터는 내가 주인이다!$",
	["zhTW"] = nil
}

local imageTriggerStrings = {
	["enUS"] = "I am the master! Do you hear?",
	["deDE"] = "Ich bin der Meister! H\195\182rt Ihr?",
	["frFR"] = "C'est moi le maître ! Vous entendez ?",
	["koKR"] = "누구나 마음속에 악마를 품고 살지...",
	["zhTW"] = nil
}

local initTriggerStrings = {
	["enUS"] = "Finally, my banishment ends!",
	["deDE"] = "Endlich hat meine Verbannung ein Ende!",
	["frFR"] = "Enfin, mon exil s'achève !",
	["koKR"] = "드디어, 내가 풀려났도다!",
	["zhTW"] = nil
}

local whirlwindTriggerStrings = {
	["enUS"] = "Leotheras the Blind gains Whirlwind",
	["deDE"] = "Leotheras der Blinde bekommt Wirbelwind",
	["frFR"] = "Leotheras l'Aveugle gagne Tourbillon",
	["koKR"] = "눈먼 레오테라스|1이;가; 소용돌이 효과를 얻었습니다.",
	["zhTW"] = nil
}

local whirlwindTrigger = whirlwindTriggerStrings[_G.GetLocale()]

function Leotheras:Init()	
	local demonPhase = demonTriggerStrings[_G.GetLocale()]
	local splitPhase = imageTriggerStrings[_G.GetLocale()]
	local initialPhase = initTriggerStrings[_G.GetLocale()]
	
	self:RegisterCombatant(BB["Leotheras the Blind"], true)
	self:RegisterCombatant(BB["Shadow of Leotheras"], false)

	-- To register a callback to a yell or emote:
	-- self:RegisterChatEvent([yell|event], localizedMobName, yellOrEmoteToTriggerOn, callbackFunction)
	
	self:RegisterChatEvent("yell", BB["Leotheras the Blind"], demonPhase, self.demonTransition)
	self:RegisterChatEvent("yell", BB["Leotheras the Blind"], splitPhase, self.splitTransition)
	self:RegisterChatEvent("yell", BB["Shadow of Leotheras"], splitPhase, self.splitTransition)		--I'm not sure if the shadow or leo himself does the yell
	self:RegisterChatEvent("yell", BB["Leotheras the Blind"], initialPhase, self.humanTransition)
	self:RegisterEvent("CHAT_MSG_SPELL_PERIODIC_CREATURE_BUFFS")
end

function Leotheras:demonTransition()
	self:SetNumberOfMobs(1)
	self:WipeRaidThreat("Leotheras")
	if not self:IsEventScheduled("LeotherasDemonTimer") then
		self:ScheduleEvent("LeotherasDemonTimer", self.humanTransition, 60, self)
	end
	if self:IsEventScheduled("LeotherasWhirlwindTimer") then
		self:CancelScheduledEvent("LeotherasWhirlwindTimer")
	end
end

function Leotheras:humanTransition()
	self:WipeRaidThreatOnMob(BB["Leotheras the Blind"])
end

function Leotheras:StartFight()
	self:SetNumberOfMobs(1)
end

function Leotheras:splitTransition()
	self:SetNumberOfMobs(2)		-- Leotheras + Shadow of Leotheras
	self:WipeRaidThreatOnMob(BB["Leotheras the Blind"])
	self:WipeRaidThreatOnMob(BB["Shadow of Leotheras"])
	if self:IsEventScheduled("LeotherasDemonTimer") then
		self:CancelScheduledEvent("LeotherasDemonTimer")
	end
	if self:IsEventScheduled("LeotherasWhirlwindTimer") then
		self:CancelScheduledEvent("LeotherasWhirlwindTimer")
	end
end

function Leotheras:CHAT_MSG_SPELL_PERIODIC_CREATURE_BUFFS(msg)
	if msg:find(whirlwindTrigger) then
		if not self:IsEventScheduled("LeotherasWhirlwindTimer") then
			self:ScheduleEvent("LeotherasWhirlwindTimer", self.humanTransition, 12, self)
		end
	end
end

table.insert(ThreatLib.UpvalueFixers, function(lib)
	ThreatLib = lib
	Leotheras = ThreatLib:GetModule("NPCCore"):GetModule(c)
end)

end
