-----------------------------------------------------------------------------

local SML = AceLibrary("SharedMedia-1.0")
local SML_statusbar = SML:List("statusbar")

-----------------------------------------------------------------------------

local AloftThreatBar = Aloft:NewModule("ThreatBar", "AceEvent-2.0")
AloftThreatBar.db = Aloft:AcquireDBNamespace("threatBar")
Aloft:RegisterDefaults("threatBar", "profile", {
	enable			= false,
	texture			= "Blizzard",
	height			= 4,
	offsets =
	{
		left		= 0,
		right		= 0,
		vertical	= -1,
	},
})

-----------------------------------------------------------------------------

local threatBarPool = { }
local profile

-----------------------------------------------------------------------------

function AloftThreatBar:UpdateAll()
	for aloftData in Aloft:IterateVisibleNameplates() do
		if profile.enable then
			if aloftData.threatBar then
				self:PlaceBar(aloftData)
				self:SetupBar(aloftData.threatBar)
			end
			self:Update(aloftData)
		else
			self:ReleaseThreatBar(aloftData)
		end
	end
	if profile.enable then
		for threatBar in pairs(threatBarPool) do
			self:SetupBar(threatBar)
		end
	end
end

-----------------------------------------------------------------------------

function AloftThreatBar:RegisterEvents()
	if profile.enable and Aloft:IsDataAvailable("unitid") then
		self:RegisterEvent("Aloft:OnNameplateShow", "Update")
		self:RegisterEvent("Aloft:OnManaDataChanged", "Update")
		self:RegisterEvent("Aloft:OnNameplateHide", "ReleaseManaBar")
	else
		self:CancelEvent("Aloft:OnNameplateShow")
		self:CancelEvent("Aloft:OnManaDataChanged")
		self:CancelEvent("Aloft:OnNameplateHide")
	end
end

function AloftThreatBar:OnInitialize()
	profile = self.db.profile
end

function AloftThreatBar:OnEnable()
	self:RegisterEvent("SharedMedia_SetGlobal", function(mediatype, override)
		if mediatype == "statusbar" then
			self:UpdateAll()
		end
	end)
	
	self:RegisterEvent("Aloft:SetAll", function(type, value)
		if profile[type] then
			profile[type] = value
			self:UpdateAll()
		end
	end)

	self:UpdateAll()
end

function AloftThreatBar:OnDisable()
	self:UnregisterAllEvents()
	
	for aloftData in Aloft:IterateVisibleNameplates() do
		self:ReleaseManaBar(aloftData)
	end
end

function AloftThreatBar:RequiresData()
	self:RegisterEvents()
	if profile.enable then
		return "threat"
	end
end

local backdropTable = { }
function AloftThreatBar:SetupBar(threatBar)
	local texture = SML:Fetch("statusbar", profile.texture)
	threatBar:SetStatusBarTexture(texture)

	backdropTable.bgFile = texture
	threatBar:SetBackdrop(backdropTable)
	threatBar:SetBackdropColor(unpack(profile.backdropColor))

	-- This manipulates the threatbar background to always display above the frame background
	local barRegion, backgroundRegion = threatBar:GetRegions()
	barRegion:SetDrawLayer("OVERLAY")
	backgroundRegion:SetDrawLayer("ARTWORK")
end

function AloftThreatBar:PlaceBar(aloftData)
	local threatBar = aloftData.threatBar
	threatBar:ClearAllPoints()
	threatBar:SetPoint("TOPLEFT", aloftData.healthBar, "BOTTOMLEFT", profile.offsets.left, profile.offsets.vertical)
	threatBar:SetPoint("BOTTOMRIGHT", aloftData.healthBar, "BOTTOMRIGHT", profile.offsets.right, profile.offsets.vertical-profile.height)
	threatBar:SetFrameLevel(0)
	threatBar:Show()
end

function AloftThreatBar:AcquireThreatBar(aloftData)
	local threatBar = aloftData.threatBar
	if not threatBar then
		threatBar = next(threatBarPool)
		if threatBar then
			threatBarPool[threatBar] = nil
			threatBar:SetParent(aloftData.nameplateFrame)
		else
			threatBar = CreateFrame("StatusBar", nil, aloftData.nameplateFrame)
			self:SetupBar(threatBar)
		end
		aloftData.threatBar = threatBar
		self:PlaceBar(aloftData)
	end
end

function AloftThreatBar:ReleaseThreatBar(aloftData)
	local threatBar = aloftData.threatBar
	if threatBar then
		threatBar:Hide()
		threatBarPool[threatBar] = true
		aloftData.threatBar = nil
	end
end

function AloftThreatBar:Update(aloftData)
	if aloftData.threat then
		self:AcquireThreatBar(aloftData)
-- TODO
--[[		
	
		local threatBar = aloftData.threatBar
		threatBar:SetStatusBarColor(unpack(color))
		threatBar:SetMinMaxValues(0, aloftData.maxMana)
		threatBar:SetValue(aloftData.mana)
]]
	else
		self:ReleaseManaBar(aloftData)
	end
end

-----------------------------------------------------------------------------
