-----------------------------------------------------------------------------

if not Aloft or not Aloft:HasModule("CommentText") then return end
local AloftCommentText = Aloft:GetModule("CommentText")
local L = AceLibrary("AceLocale-2.2"):new("AloftCommentTextOptions")
local SML = AceLibrary("SharedMedia-1.0")
local SML_font = SML:List("font")

-----------------------------------------------------------------------------

L:RegisterTranslations("enUS", function() return {
	["Comment Text"] = true,
	["Comment text options"] = true,
	["Enable"] = true,
	["Show comments on nameplates"] = true,
	["Font"] = true,
	["Sets the font for comment text"] = true,

	["Set Comment"] = true,
	["Sets the comment for your current target"] = true,
	["<Any String>"] = true,

	["Typeface"] = true,
	["Comment typeface options"] = true,
	["Font Size"] = true,
	["Sets the font height of the comment text"] = true,
	["Font Shadow"] = true,
	["Show font shadow on comment text"] = true,
	["Outline"] = true,
	["Sets the outline for comment text"] = true,

	["Position"] = true,
	["Adjust comment tag position"] = true,
	["Anchor"] = true, 
	["Sets the anchor for the comment text"] = true,
	["Anchor To"] = true, 
	["Sets the relative point on the health bar to anchor the comment text"] = true,
	["X Offset"] = true,
	["X offset of the comment text"] = true,
	["Y Offset"] = true,
	["Y offset of the comment text"] = true,
	["Alpha"] = true,
	["Sets the alpha of the comment text"] = true,
	["Color"] = true,
	["Sets the comment text color"] = true,

	["None"] = true,
	["Normal"] = true,
	["Thick"] = true,

	["NoSetComment"] = "|cffff0000You must have a target to set a comment|r",
	["CommentAdded"] = "Added |cff00ff00%s|r -> |cff00ff00%s|r",

	["Advanced"] = true,
	["Options for expert users"] = true,
	["Format"] = true,
	["Comment tag"] = true,
	["<Any tag string>"] = true,
} end)

L:RegisterTranslations("koKR", function() return {
	["Comment Text"] = "메모 글자",
	["Comment text options"] = "메모 글자 설정",
	["Enable"] = "사용",
	["Show comments on nameplates"] = "이름표에 메모를 표시합니다.",
	["Font"] = "글꼴",
	["Sets the font for comment text"] = "메모 글자의 글꼴을 설정합니다.",

	["Set Comment"] = "메모 설정",
	["Sets the comment for your current target"] = "현재 대상에 대한 메모를 설정합니다.",
	["<Any String>"] = "<문자열>",

	["Typeface"] = "서체",
	["Comment typeface options"] = "메모 서체 설정",
	["Font Size"] = "글꼴 크기",
	["Sets the font height of the comment text"] = "메모 글자의 글꼴 높이를 설정합니다.",
	["Font Shadow"] = "글꼴 그림자",
	["Show font shadow on comment text"] = "메모 글자에 그림자를 표시합니다.",
	["Outline"] = "테두리",
	["Sets the outline for comment text"] = "메모 글자에 테두리를 설정합니다.",

	["Position"] = "위치",
	["Adjust comment tag position"] = "메모 태그의 위치를 조절합니다.",
	["Anchor"] = "앵커", 
	["Sets the anchor for the comment text"] = "메모 글자의 앵커를 설정합니다.",
	["Anchor To"] = "앵커 위치", 
	["Sets the relative point on the health bar to anchor the comment text"] = "생명력바에서 메모 글자의 앵커 위치를 설정합니다.",
	["X Offset"] = "X 좌표",
	["X offset of the comment text"] = "메모 글자의 X 좌표입니다.",
	["Y Offset"] = "Y 좌표",
	["Y offset of the comment text"] = "메모 글자의 Y 좌표입니다.",
	["Alpha"] = "투명도",
	["Sets the alpha of the comment text"] = "메모 글자의 투명도를 설정합니다.",
	["Color"] = "색상",
	["Sets the comment text color"] = "메모 글자의 색상을 설정합니다.",

	["None"] = "없음",
	["Normal"] = "기본",
	["Thick"] = "굵게",

	["NoSetComment"] = "|cffff0000메모를 설정하려면 대상이 있어야 합니다.|r",
	["CommentAdded"] = "|cff00ff00%s|r -> |cff00ff00%s|r 추가됨",

	["Advanced"] = "고급",
	["Options for expert users"] = "고급 사용자를 위한 설정",
	["Format"] = "형식",
	["Comment tag"] = "메모 태그",
	["<Any tag string>"] = "<태그 문자열>",
} end)

-----------------------------------------------------------------------------

Aloft.Options.args.comment =
{
	type = 'group',
	name = L["Comment Text"],
	desc = L["Comment text options"],
	disabled = function() return not Aloft:IsActive() end,
	args =
	{
		enable =
		{
			type = 'toggle',
			name = L["Enable"],
			desc = L["Show comments on nameplates"],
			get = function() return AloftCommentText.db.profile.enable end,
			set = function(v) AloftCommentText.db.profile.enable = v AloftCommentText:UpdateTag() AloftCommentText:UpdateAll() end,
			order = 1
		},
		setComment =
		{
			type = 'text',
			name = L["Set Comment"],
			desc = L["Sets the comment for your current target"],
			usage = L["<Any String>"],
			disabled = function() return not AloftCommentText.db.profile.enable end,
			get = function() return "" end,
			set = function(v) 
					local setFor = Aloft:GetModule("CommentData"):SetCommentForTarget(v)
					if setFor then
						Aloft:Print(string.format(L["CommentAdded"], setFor, v))
					else
						Aloft:Print(L["NoSetComment"])
					end
				  end,
			order = 2
		},
		typeface =
		{
			type = "group",
			name = L["Typeface"],
			desc = L["Comment typeface options"],
			disabled = function() return not AloftCommentText.db.profile.enable end,
			args =
			{
				font =
				{
					type = "text", 
					name = L["Font"], 
					desc = L["Sets the font for comment text"],
					get = function() return AloftCommentText.db.profile.font end,
					set = function(v) AloftCommentText.db.profile.font = v AloftCommentText:UpdateAll() end,
					validate = SML_font,
				},
				fontSize =
				{
					type = 'range',
					name = L["Font Size"],
					desc = L["Sets the font height of the comment text"],
					max = 16,
					min = 5,
					step = 1,
					get = function() return AloftCommentText.db.profile.fontSize end,
					set = function(value) AloftCommentText.db.profile.fontSize = value AloftCommentText:UpdateAll() end
				},
				shadow =
				{
					type = 'toggle',
					name = L["Font Shadow"],
					desc = L["Show font shadow on comment text"],
					get = function() return AloftCommentText.db.profile.shadow end,
					set = function(v) AloftCommentText.db.profile.shadow = v AloftCommentText:UpdateAll() end
				},
				outline =
				{
					type = 'text',
					name = L["Outline"],
					desc = L["Sets the outline for comment text"],
					get = function() return AloftCommentText.db.profile.outline end,
					set = function(value) AloftCommentText.db.profile.outline = value AloftCommentText:UpdateAll() end,
					validate = { [""] = L["None"], ["OUTLINE"] = L["Normal"], ["THICKOUTLINE"] = L["Thick"] },
				},
			},
		},
		position =
		{
			type = 'group',
			name = L["Position"],
			desc = L["Adjust comment tag position"],
			disabled = function() return not AloftCommentText.db.profile.enable end,
			args =
			{
				anchor = {
					type = "text", 
					name = L["Anchor"], 
					desc = L["Sets the anchor for the comment text"],
					get = function() return AloftCommentText.db.profile.point end,
					set = function(v) AloftCommentText.db.profile.point = v AloftCommentText:UpdateAll() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				anchorto = {
					type = "text", 
					name = L["Anchor To"], 
					desc = L["Sets the relative point on the health bar to anchor the comment text"],
					get = function() return AloftCommentText.db.profile.relativeToPoint end,
					set = function(v) AloftCommentText.db.profile.relativeToPoint = v AloftCommentText:UpdateAll() end,
					validate = {"TOPLEFT", "TOP", "TOPRIGHT", "LEFT", "CENTER", "RIGHT", "BOTTOMLEFT", "BOTTOM", "BOTTOMRIGHT"},
				},
				offsetX =
				{
					type = 'range',
					name = L["X Offset"],
					desc = L["X offset of the comment text"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return AloftCommentText.db.profile.offsetX end,
					set = function(v) AloftCommentText.db.profile.offsetX = v AloftCommentText:UpdateAll() end
				},
				offsetY =
				{
					type = 'range',
					name = L["Y Offset"],
					desc = L["Y offset of the comment text"],
					min = -32,
					max = 32,
					step = 1,
					get = function() return AloftCommentText.db.profile.offsetY end,
					set = function(v) AloftCommentText.db.profile.offsetY = v AloftCommentText:UpdateAll() end
				},
			},
		},
		alpha =
		{
			type = 'range',
			name = L["Alpha"],
			desc = L["Sets the alpha of the comment text"],
			min = 0,
			max = 1.0,
			step = 0.05,
			disabled = function() return not AloftCommentText.db.profile.enable end,
			get = function() return AloftCommentText.db.profile.alpha end,
			set = function(v) AloftCommentText.db.profile.alpha = v AloftCommentText:UpdateAll() end
		},
		color =
		{
			type = 'color',
			name = L["Color"],
			desc = L["Sets the comment text color"],
			disabled = function() return not AloftCommentText.db.profile.enable end,
			get = function() return unpack(AloftCommentText.db.profile.color) end,
			set = function(r, g, b, a) AloftCommentText.db.profile.color = { r, g, b, a } AloftCommentText:UpdateAll() end,
		},
		advanced  =
		{
			type = 'group',
			name = L["Advanced"],
			desc = L["Options for expert users"],
			order = -1,
			disabled = function() return not AloftCommentText.db.profile.enable end,
			args =
			{
				format = 
				{
					type = 'text',
					name = L["Format"],
					desc = L["Comment tag"],
					usage = L["<Any tag string>"],
					get = function() return AloftCommentText.db.profile.format end,
					set = function(v) AloftCommentText.db.profile.format = v Aloft:DetermineDataSources() AloftCommentText:UpdateAll() end,
				}
			},
		},
	},
}

-----------------------------------------------------------------------------
